==> haskell-optparse-simple-0.1.1.4-503-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-simple
version:              0.1.1.4
visibility:           public
id:                   optparse-simple-0.1.1.4-FoaigDzjlxMDDD9JCNI3st
key:                  optparse-simple-0.1.1.4-FoaigDzjlxMDDD9JCNI3st
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  f1b6a4b57ecc4c76b657b3109d46b920
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-simple
hs-libraries:         HSoptparse-simple-0.1.1.4-FoaigDzjlxMDDD9JCNI3st
depends:
    base-4.17.2.1 githash-0.1.6.3-B0dUCoK53b5JeMVhe3ZZZz
    optparse-applicative-0.18.1.0-5pRc89gLzX8JqTyOujyDZt
    template-haskell-2.19.0.0 th-compat-0.1.6-LSPGkh6JNWp5Mbyc5j9P7X
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.1.4-504-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-simple
version:              0.1.1.4
visibility:           public
id:                   optparse-simple-0.1.1.4-ByaGuNzMRgQ4Va79c8PWeb
key:                  optparse-simple-0.1.1.4-ByaGuNzMRgQ4Va79c8PWeb
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  631cf0921943a02b8fdef4b430cce056
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-simple
hs-libraries:         HSoptparse-simple-0.1.1.4-ByaGuNzMRgQ4Va79c8PWeb
depends:
    base-4.17.2.1 githash-0.1.6.3-5nQf0PyKAyv5qIlWDyr7Nf
    optparse-applicative-0.18.1.0-EdEjIHpfurx5EyqDyJ3l4u
    template-haskell-2.19.0.0 th-compat-0.1.6-EBfHTxkikDEHBQOvNLNZ1o
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
